import { useTheme } from '@mui/material';
import React, { useEffect } from 'react';
import { FlowElement, Handle, Position } from 'react-flow-renderer';
import styles from './entitypill.module.scss';

// export const Handless = {
//   entity: {
//     attributes: 'attributesHandle',
//     relations: 'relationsHandle',
//   },
// };

/** Links need handles to what they are connected to (and which side) */
export enum Handles {
  RelationLeft = 'leftEntityHandle', //target
  RelationRight = 'rightEntityHandle', //target
  ToAttributeHandle = 'attributesHandle', //target
  ToRelation = 'relationsHandle', //source
  OnAttribute = 'onAttributeHandle', //source
  ReceiveFunction = 'receiveFunctionHandle', //target
  FunctionBase = 'functionHandle_', // + name from FunctionTypes args //source
}

/**
 * Component to render an entity flow element
 * @param {FlowElement<EntityData>)} param0 The data of an entity flow element.
 */
export const EntityRFPill = React.memo(({ data }: { data: any }) => {
  const theme = useTheme();

  // TODO: Change flow element width when text overflows
  // const data = entityNode.data as EntityData;
  // const animation = data.fadeIn ? styles.entityFade : '';

  return (
    <div
      className={styles.entity}
      style={{
        background: theme.palette.queryBuilder.entity.background,
        fontFamily: 'monospace',
        color: theme.palette.queryBuilder.entity.text,
        // borderTop: `4px solid ${theme.palette.queryBuilder.entity.accent}`,
        // borderBottom: `6px solid ${theme.palette.queryBuilder.entity.accent}`,
      }}
    >
      <Handle
        id={Handles.ToRelation}
        type="source"
        position={Position.Bottom}
        className={styles.handleLeft}
      />
      <Handle
        id={Handles.ToAttributeHandle}
        type="target"
        position={Position.Bottom}
        className={styles.handleBottom}
      />
      {/* <Handle
        id={Handles.ReceiveFunction}
        type="target"
        position={Position.Bottom}
        className={styles.handleFunction + ' ' + styles.handleFunctionEntity}
      /> */}
      <div
        className={styles.contentWrapper}
        style={{
          color: theme.palette.queryBuilder.entity.text,
        }}
      >
        <span>{data.name}</span>
      </div>
    </div>
  );
});
