import { ColorPaletteConfig } from '@graphpolaris/shared/data-access/store';
import { ThemeOptions } from '@mui/material/styles';

/** Maps our color palette config (stored in redux) to the mui 5 theme format */
export default function MapColorsConfigToMuiTheme(
  colorsConfig: ColorPaletteConfig
): ThemeOptions {
  return {
    palette: {
      mode: colorsConfig.darkMode ? 'dark' : 'light',

      ...(colorsConfig.darkMode
        ? {
            primary: colorsConfig.darkPalette.primary,
            secondary: colorsConfig.darkPalette.secondary,
            dataPointColors: colorsConfig.darkPalette.custom.dataPointColors,
            queryBuilder: {
              entity: {
                background:
                  colorsConfig.darkPalette.custom.queryBuilder.entity
                    .background,
                accent:
                  colorsConfig.darkPalette.custom.queryBuilder.entity.accent,
                text: colorsConfig.darkPalette.custom.queryBuilder.entity.text,
              },
            },
          }
        : {
            primary: colorsConfig.lightPalette.primary,
            secondary: colorsConfig.lightPalette.secondary,
            dataPointColors: colorsConfig.lightPalette.custom.dataPointColors,
            queryBuilder: {
              entity: {
                background:
                  colorsConfig.lightPalette.custom.queryBuilder.entity
                    .background,
                accent:
                  colorsConfig.lightPalette.custom.queryBuilder.entity.accent,
                text: colorsConfig.lightPalette.custom.queryBuilder.entity.text,
              },
            },
          }),
    },
  };
}
